# Security Policy

<img align="right" src=".github/rayna.png" width="100">

Thank you for helping keep Barndoor and its customers secure, one patch at a time!

## Reporting Security Issues

If you believe you have discovered a bug, defect, flaw or vulnerability in this project, please,

- If it is not sensitive in nature:
    - Open an issue/PR in the relevant repository

- If you believe it is sensitive in nature:
    - Submit your findings to our [Vulnerability Disclosure Program](https://docs.google.com/forms/d/e/1FAIpQLScKkUDCkghzOyg7cMBKcJYewTcOvJkY9G0KCaL5sREmEow8Vw/viewform?usp=header)

--,  with as much information as possible.
